flash: Rename copy_flash to flash_copy

Change-Id: If449889fca3370e25a65719d2f5c5ec90258d633
Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
diff --git a/vpnor/flash.cpp b/vpnor/flash.cpp
index b2e0134..e18f3b8 100644
--- a/vpnor/flash.cpp
+++ b/vpnor/flash.cpp
@@ -108,16 +108,16 @@
 }
 
 /*
  * copy_flash() - Copy data from the virtual pnor into a provided buffer
  * @context:    The mbox context pointer
  * @offset:     The pnor offset to copy from (bytes)
  * @mem:        The buffer to copy into (must be of atleast 'size' bytes)
  * @size:       The number of bytes to copy
  * Return:      Number of bytes copied on success, otherwise negative error
  *              code. copy_flash will copy at most 'size' bytes, but it may
  *              copy less.
  */
-int64_t copy_flash(struct mbox_context* context, uint32_t offset, void* mem,
+int64_t flash_copy(struct mbox_context* context, uint32_t offset, void* mem,
                    uint32_t size)
 {
     vpnor::partition::Table* table;
@@ -108,16 +108,16 @@
 
 /*
- * copy_flash() - Copy data from the virtual pnor into a provided buffer
+ * flash_copy() - Copy data from the virtual pnor into a provided buffer
  * @context:    The mbox context pointer
  * @offset:     The pnor offset to copy from (bytes)
@@ -108,16 +108,16 @@
  * @size:       The number of bytes to copy
  * Return:      Number of bytes copied on success, otherwise negative error
- *              code. copy_flash will copy at most 'size' bytes, but it may
+ *              code. flash_copy will copy at most 'size' bytes, but it may
  *              copy less.
  */